Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(176)

Unified Diff: base/trace_event/trace_event_memory.h

Issue 1100773004: base: Remove most uses of MessageLoopProxy (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Added some missing includes. Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « base/trace_event/trace_event_impl.cc ('k') | base/trace_event/trace_event_memory.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/trace_event/trace_event_memory.h
diff --git a/base/trace_event/trace_event_memory.h b/base/trace_event/trace_event_memory.h
index 8e70020a0896debe59ed2ada0e8c23acc5ef710a..e2b3ae93060ade693c67a6717113f2ab9e42ebe9 100644
--- a/base/trace_event/trace_event_memory.h
+++ b/base/trace_event/trace_event_memory.h
@@ -20,7 +20,7 @@
namespace base {
-class MessageLoopProxy;
+class SingleThreadTaskRunner;
namespace trace_event {
@@ -35,15 +35,14 @@ class BASE_EXPORT TraceMemoryController
typedef void (*HeapProfilerStopFunction)();
typedef char* (*GetHeapProfileFunction)();
// |message_loop_proxy| must be a proxy to the primary thread for the client
// process, e.g. the UI thread in a browser. The function pointers must be
// pointers to tcmalloc heap profiling functions; by avoiding direct calls to
// these functions we avoid a dependency on third_party/tcmalloc from base.
- TraceMemoryController(
- scoped_refptr<MessageLoopProxy> message_loop_proxy,
- HeapProfilerStartFunction heap_profiler_start_function,
- HeapProfilerStopFunction heap_profiler_stop_function,
- GetHeapProfileFunction get_heap_profile_function);
+ TraceMemoryController(scoped_refptr<SingleThreadTaskRunner> task_runner,
+ HeapProfilerStartFunction heap_profiler_start_function,
+ HeapProfilerStopFunction heap_profiler_stop_function,
+ GetHeapProfileFunction get_heap_profile_function);
virtual ~TraceMemoryController();
// base::trace_event::TraceLog::EnabledStateChangedObserver overrides:
@@ -65,7 +64,7 @@ class BASE_EXPORT TraceMemoryController
bool IsTimerRunningForTest() const;
// Ensures the observer starts and stops tracing on the primary thread.
- scoped_refptr<MessageLoopProxy> message_loop_proxy_;
+ scoped_refptr<SingleThreadTaskRunner> task_runner_;
// Pointers to tcmalloc heap profiling functions. Allows this class to use
// tcmalloc functions without introducing a dependency from base to tcmalloc.
« no previous file with comments | « base/trace_event/trace_event_impl.cc ('k') | base/trace_event/trace_event_memory.cc » ('j') | no next file with comments »
@@ -35,15 +35,14 @@ class BASE_EXPORT TraceMemoryController
typedef void (*HeapProfilerStopFunction)();
typedef char* (*GetHeapProfileFunction)();
- // |message_loop_proxy| must be a proxy to the primary thread for the client
+ // |task_runner| must be a task runner for the primary thread for the client
// process, e.g. the UI thread in a browser. The function pointers must be
// pointers to tcmalloc heap profiling functions; by avoiding direct calls to

Powered by Google App Engine
This is Rietveld 408576698